<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_VE">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="214"/>
        <source>Drop Error</source>
        <translation>Error al remover</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="215"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Archivo/URL &apos;%1&apos; no puede ser empotrado en la barra de lanzadores por ahora</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="321"/>
        <source>Drop application
icons here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Mover a la izquierda</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Mover a la derecha</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Remover de la barra de lanzadores</translation>
    </message>
</context>
</TS>
